@@ -52,3 +52,14 @@ def update(data, path, value):
         data[int(path)] = value
     else:
         data[path] = value
+
+def ignore_none_item(data):
+    result = {}
+    for key, value in data.items():
+        if value is None:
+            continue
+        if not value:
+            if isinstance(value, (list, dict)):
+                continue
+        result[key] = value
+    return result
