@@ -7,6 +7,7 @@ import binascii
 import base64
 import bizerror
 import typing
+from decimal import Decimal
 
 try:
     text_type = unicode
@@ -35,6 +36,7 @@ def char_force_to_int(value):
 
 def force_bytes(value, encoding="utf-8"):
     if isinstance(value, text_type):
+        encoding = encoding or "utf-8"
         return value.encode(encoding)
     else:
         return value
@@ -50,12 +52,25 @@ def force_text(value, encoding=None):
         encodings = [encoding]
     for encoding in encodings:
         try:
-            print(value, encoding)
             return value.decode(encoding)
         except UnicodeDecodeError:
             pass
     raise UnicodeDecodeError()
 
+def force_int(value):
+    if isinstance(value, int):
+        return value
+    elif isinstance(value, str):
+        return int(value)
+    elif isinstance(value, bytes):
+        return int(value.decode())
+    elif isinstance(value, float):
+        return int(value)
+    elif isinstance(value, Decimal):
+        return int(value)
+    else:
+        raise RuntimeError("force_int failed: value={}".format(value))
+
 def wholestrip(text):
     """Remove all white spaces in text. White spaces are ' \t\n\r\x0b\x0c\u3000'.
     """
@@ -104,7 +119,10 @@ def is_hex_digits(text):
 def join_lines(text):
     """Join multi-lines into single line.
     """
-    return "".join(text.splitlines())
+    if isinstance(text, str):
+        return "".join(text.splitlines())
+    elif isinstance(text, bytes):
+        return b"".join(text.splitlines())
 
 
 def is_urlsafeb64_decodable(text):
@@ -194,7 +212,7 @@ def smart_get_binary_data(text: typing.Union[str, bytes]) -> bytes:
     else:
         raise bizerror.NotSupportedTypeToCast()
 
-def is_chinese_character(c):
+def is_chinese_character(c: str) -> bool:
     """
     Block                                   Range       Comment
     CJK Unified Ideographs                  4E00-9FFF   Common
@@ -224,3 +242,33 @@ def is_chinese_character(c):
     if 0x2F800 <=c <= 0x2FA1F:
         return True
     return False
+
+def binarify(data: typing.Union[str, bytes]) -> str:
+    if isinstance(data, str):
+        data = data.encode("utf-8")
+    return "".join(["{:08b}".format(x) for x in data])
+
+def unbinarify(text: typing.Union[str, bytes]) -> bytes:
+    if not text:
+        return b""
+    if isinstance(text, bytes):
+        text = text.decode("utf-8")
+    from .listutils import chunk
+    return bytes([int(x, 2) for x in chunk(text, 8)])
+
+def ints2bytes(ints: typing.List[int]) -> bytes:
+    result = b""
+    for value in ints:
+        if value:
+            result += int2bytes(value)
+        else:
+            result += b'\x00'
+    return result
+
+def int2bytes(value: int):
+    bs = []
+    while value:
+        bs.append(value % 256)
+        value = value // 256
+    bs.reverse()
+    return bytes(bs)
